#
# These are the definitions for doc2lt and doctext HTML output
#
#
# Note on the use of <LISTING></LISTING> and other monotype fonts
# Many browsers choose a different SIZE font for listing; IE4 gives you
# no control over the size, while at least Netscape lets you set the size
# correctly (it should be the SAME as the other fonts).
# You might consider <FONT SIZE=+1>...</FONT> inside the listing.
# HTML 3.2 specifies <PRE> instead of <LISTING>
#
# Doc2lt single line entry
key        %n%p<CODE>%1</CODE>
synopsis   %n<PRE>%1</PRE>
definition %n<B>%1</B>%n
section    %n<H2>%1</H2>%n
s_synopsis %n<H2>Synopsis</H2>%n<PRE>%n
e_synopsis %n</PRE>%n
em_dash    
eof        %n</BODY></HTML>%n
bof        <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML3.2 EN">%n<HTML>%n\
<HEAD>%n<META NAME="GENERATOR" CONTENT="DOCTEXT">%n
bop
eop
# Arglist form
s_arg_list %n<DL>%n
s_arg_inlist %n<DT><B>
e_arg_inlist </B> 
s_defn_inlist <DD> 
e_defn_inlist %n
e_arg_list </DL>%n
# Here's an alternative
#s_arg_list %n<TABLE>
#s_arg_inlist %n<TR><TD>
#e_arg_inlist </TD>
#s_defn_inlist<TD>
#e_defn_inlist</TD></TR>
#e_arg_list </TABLE>%n
#
# individual arg form
s_arg      %n<DL><DT><B>
s_defn     <DD> 
e_defn     %n</DL>%n
e_arg      </B> 
s_doctext_verbatim <BR>
e_doctext_verbatim %n
s_caption  <CENTER><B>
e_caption  </B></CENTER>
picture    <A IMG="%1"></A>
location   <P><B>Location:</B>%1<P>
# Only do the actual title
# Without a title, the page will be broken.
mantitle   <TITLE>%1</TITLE>%n</HEAD>%n<BODY BGCOLOR="FFFFFF">%n<H1 id="%1">%1</H1>%n
# mantitlemany is used for files containing multiple manual pages
mantitlemany   %n<H1 id="%1">%1</H1>%n
# bofmanyend is needed for mantitlemany
bofmanyend  <TITLE>Manual Pages</TITLE>%n</HEAD>%n<BODY BGCOLOR="FFFFFF">%n
anchor	    <a name="%1"></a>

